##### Analysis of tellurite resistance in selected soil-evolved clones #####
# J. P. J. Hall, August 2018

rm(list=ls())
d_scaled <- read.table("./data/SuppTab9.csv",
           header=TRUE, sep=",")

library(MESS)
library(plyr)

# Calculate area under the curve as the response variable
#  cf. Bottery et al., Nat Eco Evo, 2017
d <- with(d_scaled, ddply(d_scaled, .(cln_name, tech_rep, actp.status), 
                          function(x) auc(x$tell_conc, x$OD600_scaled, type="linear")))
head(d)

ggplot(data=d, aes(x=actp.status, y=V1, col=cln_name, shape=tech_rep)) + 
  geom_point(position=position_dodge(width=0.5))


# Analyse in a similar way to the disc diffusion assay

boxplot(d$V1 ~ d$actp.status)
bartlett.test(x = d$V1, g = d$actp.status) # p =0.6865
fligner.test(x = d$V1, g = d$actp.status) #  p = 0.8028
library(car)
leveneTest(d$V1 ~ d$actp.status) # 0.9979

mod00 <- lm(data=d, V1 ~ actp.status)
qqPlot(resid(mod00))
shapiro.test(resid(mod00)) # 0.3749

# looks fine

# Measure contribution of clone-clone variation
library(nlme)
mod0 <- gls(V1 ~ actp.status,
            method="REML", data=d)
mod1 <- lme(V1 ~ actp.status,
            random= ~1|cln_name,
            data=d, method="REML")
anova(mod0,mod1) # 0.0023
loglik <- 2*(c(logLik(mod1)-logLik(mod0)))
0.5 * (1 - pchisq(loglik, 1))
# random effect of clone is helpful (p = 0.001170957)

mod1_ml <- update(mod1, .~., method="ML")
drop1(mod1_ml, test="Chisq")

#             Df    AIC     LRT Pr(>Chi)
# <none>         42.359                 
# actp.status  1 40.963 0.60427    0.437
# No significant effect of actp status


# Is there an effect of clone?
boxplot(d$V1 ~ d$cln_name)
bartlett.test(x = d$V1, g = d$cln_name) # p = 0.2413
fligner.test(x = d$V1, g = d$cln_name) #  p = 0.9839

leveneTest(d$V1 ~ d$cln_name) # 0.8883

mod02 <- lm(data=d, V1~cln_name)
qqPlot(resid(mod02))
shapiro.test(resid(mod02)) # 0.9179

anova(mod02)
#           Df Sum Sq Mean Sq F value   Pr(>F)   
# cln_name   7 6.2196 0.88852  6.2186 0.001225 **
# Residuals 16 2.2861 0.14288

t(t(coef(mod02)))

# (Intercept)            4.0319073
# cln_nameA.02.65.G.011  0.5088313
# cln_nameA.10.65.G.006 -0.4981824 # low 
# cln_nameB.09.65.G.029  0.4050505
# cln_nameC.01.65.G.021  1.1564468 # high
# cln_nameC.02.65.G.016  0.8947572
# cln_nameC.09.65.G.032  0.9738172 # high
# cln_nameC.10.65.G.027  0.5808860


# Like the disc diffusion assay, we can detect differences between the evolved clones
#   but there are no significant differences between clones with disrupted and non-disrupted actP.
